VERSION_NUMBER = "1.0.4-beta"

GYAT2PY_MAPPINGS = {
    "hawk": "try",
    "tuah": "except",
    "spit\s+on\s+that\s+thang": "finally",
    "its\s+giving": "return",
    "fanum\s+tax": "-",
    "rizz": "+",
    "yap": "print",
    "Aura": "True",
    "Cooked": "False",
    "bop": "def",
    "let\s+him\s+cook": "while",
    "glaze": "import",
    "lock\s+in": "from",
    "skibidi": "class",
    "chat\s+is\s+this\s+real": "if",
    "yo\s+chat": "elif",
    "only\s+in\s+ohio": "else",
    "mewing": "for",
    "just\s+put\s+the\s+fries\s+in\s+the\s+bag\s+bro": "break",
    "edge": "continue",
    "sus": "assert",
    "crashout": "raise",
    "pookie": "with",
    "ahh": "as",
    "GOAT": "global",
    "motion": "nonlocal",
    "delulu": "del",
    "pause no diddy": "yield from",
    "pause": "yield",
    "NPC": "None",
    "unc": "self",
    "huzz": "range",
    "sigma\s+twin": ">=",
    "beta\s+twin": "<=",
    "twin": "==",
    "sigma": ">",
    "beta": "<",
    "diddy": "in",
    "pluh": "pass"
}
